@@ -1,8 +1,9 @@
 #!/bin/sh
 ### install.sh - installation skript for German fortunes
-### -- Andreas Tille <tille@debian.org>
-###
-VERSION="0.11"
+### Andreas Tille <tille@debian.org>
+### GPL or EUPL
+
+VERSION="0.26"
 
 PREFIX=${PREFIX-"/usr/local"}
 
@@ -23,11 +24,6 @@ INSTDIR=$FORTUNESDIR/de
 
 SCRIPTSEARCH=${SCRIPTSEARCH:-"$FORTUNESDIR"}
 
-UTF8=no
-if [ _"$1" = _"-utf8" ] ; then
-   UTF8=yes
-fi
-
 ### Rezepte
 REZEPTE=`find rezepte -maxdepth 1 -type d | sed "s?rezepte/??" | sed "/rezepte/d"`
 REZEPTTMP=rezept.tmp.$$
@@ -35,12 +31,12 @@ REZEPTTMP=rezept.tmp.$$
 str_it () {
   dat=`basename $1`
   cp -a -f $1 $INSTDIR
-  if [ "$UTF8" = "yes" ] ; then
-     # recode to UTF-8
-     recode latin1..u8 $INSTDIR/"$dat"
+  # if [ "$UTF8" = "yes" ] ; then
+     # Data files now are just UTF-8 encoded
+     # recode latin1..u8 $INSTDIR/"$dat"
      # Create file with extension *.u8 to give Debian fortune binary a hint to this encoding
      ln -s "$dat" $INSTDIR/"$dat".u8
-  fi
+  # fi
   strfile -s $INSTDIR/"$dat"
 }
 
@@ -53,18 +49,18 @@ fi
 
 if [ -d $INSTDIR ] || mkdir -p $INSTDIR
 then
-# nicht vernderte Datenfiles
+# nicht veränderte Datenfiles
  for spruch in $FORTUNES
  do
   str_it data/$spruch
  done
-# Ungeprfte und unsortierte Datenfiles
+# Ungeprüfte und unsortierte Datenfiles
  for spruch in $FORTUNESMORE
  do
   str_it data-more/$spruch
  done
 # Datenfiles, die einzeln besser pflegbar sind, aber zu einem
-# Fortune-File zusammengefat werden
+# Fortune-File zusammengefaßt werden
  mkdir tmp
  for dir in $DIRS
  do
@@ -140,7 +136,7 @@ done
 
 if [ -f ${BINDIR}/fortune ] ; then
   if [ -f ${BINDIR}/fortune.en -o -L ${BINDIR}/fortune ] ; then
-    echo "Es scheint schon eine frhere Version von fortunes-de installiert worden zu sein."
+    echo "Es scheint schon eine frühere Version von fortunes-de installiert worden zu sein."
     echo "Verzichte auf das Umbenennen von ${BINDIR}/fortune."
   else
     mv ${BINDIR}/fortune ${BINDIR}/fortune.en
@@ -168,5 +164,3 @@ if [ -f ${MAN6DIR}/fortune.6.gz ] ; then
   fi
 fi
 ln -sf $mainman $MAN6DIR/fortune.6
-
-
